@@ -25,6 +25,7 @@ from yellowdog_client.model import (
     CloudProvider,
     Group,
     ImageOsType,
+    InternalUser,
     Keyring,
     MachineImage,
     MachineImageFamily,
@@ -39,7 +40,9 @@ from yellowdog_client.model import (
 from yellowdog_client.model.exceptions import InvalidRequestException
 
 from yellowdog_cli.utils.entity_utils import (
+    clear_application_caches,
     clear_compute_source_template_cache,
+    clear_group_caches,
     clear_image_family_search_cache,
     find_compute_requirement_template_id_by_name,
     find_compute_source_template_id_by_name,
@@ -529,7 +532,7 @@ def create_image_family(resource):
         if e.response.status_code == 404:
             # This will create the Image Family and all of its constituent
             # Image Group/Image resources
-            image_family = CLIENT.images_client.add_image_family(image_family)
+            image_family = _create_image_family(image_family, fq_name)
             print_log(f"Created Machine Image Family '{fq_name}' ('{image_family.id}')")
             if ARGS_PARSER.quiet:
                 print(image_family.id)
@@ -1017,6 +1020,10 @@ def create_group(resource: Dict):
 
         current_role_ids = {role.role.id for role in group.roles}
 
+        if current_role_ids == new_role_ids:
+            print_log("No Role additions or deletions required")
+            return
+
         role_ids_to_remove = current_role_ids - new_role_ids
         for role_id in role_ids_to_remove:
             CLIENT.account_client.remove_role_from_group(group.id, role_id)
@@ -1041,6 +1048,7 @@ def create_group(resource: Dict):
             _get_model_object(RN_ADD_GROUP_REQUEST, resource)
         )
         print_log(f"Created Group '{group.name}' ({group.id})")
+        clear_group_caches()
         update_roles(group)
 
     def update_group(group_id: str):
@@ -1095,6 +1103,10 @@ def create_application(resource: Dict):
             group.id for group in get_application_groups(CLIENT, app.id)
         }
 
+        if current_group_ids == new_group_ids:
+            print_log("No Group additions or deletions required")
+            return
+
         group_ids_to_remove = current_group_ids - new_group_ids
         for group_id in group_ids_to_remove:
             CLIENT.account_client.remove_application_from_group(group_id, app.id)
@@ -1128,6 +1140,7 @@ def create_application(resource: Dict):
         app = app_response.application
         print_log(f"Created Application '{app.name}' ({app.id})")
         show_key_and_secret(app_response.apiKey)
+        clear_application_caches()
         update_groups(app)
 
     def update_application(app_id: str):
@@ -1159,10 +1172,9 @@ def create_application(resource: Dict):
 
 def update_user(resource: Dict):
     """
-    Update a user. Will also add or remove groups specified
-    by their names or IDs.
+    Update a user (specified by name or ID). Will also add or remove
+    groups specified by their names or IDs.
     """
-
     name = resource.get(PROP_NAME)
     id = resource.get(PROP_ID)
 
@@ -1178,11 +1190,11 @@ def update_user(resource: Dict):
         # Convert group names to IDs
         new_group_ids = set()
         for group_name in groups:
-            app_id = get_group_id_by_name(CLIENT, group_name)
-            if app_id is None:
+            group_id = get_group_id_by_name(CLIENT, group_name)
+            if group_id is None:
                 print_warning(f"Group name '{group_name}' not found ... ignoring")
             else:
-                new_group_ids.add(app_id)
+                new_group_ids.add(group_id)
 
     def update_groups(user: User):
         """
@@ -1193,12 +1205,16 @@ def update_user(resource: Dict):
 
         current_group_ids = {group.id for group in get_user_groups(CLIENT, user.id)}
 
+        if current_group_ids == new_group_ids:
+            print_log("No Group additions or deletions required")
+            return
+
         group_ids_to_remove = current_group_ids - new_group_ids
         for group_id in group_ids_to_remove:
             CLIENT.account_client.remove_user_from_group(group_id, user.id)
             print_log(
                 f"Removed Group '{get_group_name_by_id(CLIENT, group_id)}' "
-                f"from User ({group_id})"
+                f"({group_id})"
             )
 
         group_ids_to_add = new_group_ids - current_group_ids
@@ -1206,13 +1222,16 @@ def update_user(resource: Dict):
             CLIENT.account_client.add_user_to_group(group_id, user.id)
             print_log(
                 f"Added Group '{get_group_name_by_id(CLIENT, group_id)}' "
-                f"to User ({group_id})"
+                f"({group_id})"
             )
 
-    # Main logic: try name then ID if present
+    # Main logic: try name then ID if present; check for ID match
     user = None
     if name is not None:
         user = get_user_by_name_or_id(CLIENT, name)
+    if user is not None and id is not None:
+        if user.id != id:
+            raise Exception(f"User name '{name}' and supplied ID do not match")
     if user is None and id is not None:
         user = get_user_by_name_or_id(CLIENT, id)
 
@@ -1221,11 +1240,53 @@ def update_user(resource: Dict):
             f"User '{name}' not found; Users cannot be created using "
             "the CLI, please use the YellowDog Portal"
         )
-    elif groups is not None:
-        print_log(f"Updating Groups for User '{name}' ({user.id})")
+        return
+
+    username = user.username if isinstance(user, InternalUser) else user.name
+
+    if groups is not None:
+        print_log(f"Updating Groups for User '{username}' ({user.id})")
         update_groups(user)
     else:
-        print_log(f"Nothing to do for User '{name}' ({user.id})")
+        print_log(f"Nothing to do for User '{username}' ({user.id})")
+
+
+def _create_image_family(
+    image_family: MachineImageFamily, fq_name: str
+) -> MachineImageFamily:
+    """
+    Creates a new image family. Only one image group can be added at the time of
+    image family creation, so any additional image groups must be added separately.
+    """
+
+    # Remove all except the first image group; keep the rest as a separate list
+    image_groups = image_family.imageGroups
+    if image_groups is not None:
+        image_family.imageGroups = image_groups[:1]
+        image_groups = image_groups[1:]  # Remaining image groups
+
+    # Create the image family
+    try:
+        image_family = CLIENT.images_client.add_image_family(image_family)
+    except Exception as e:
+        raise Exception(f"Failed to create Machine Image Family '{fq_name}': {e}")
+
+    if image_groups is None or len(image_groups) == 0:
+        return image_family
+
+    # Create any additional image groups
+    for image_group in image_groups:
+        try:
+            image_group = CLIENT.images_client.add_image_group(
+                image_family, image_group
+            )
+        except Exception as e:
+            raise Exception(
+                f"Failed to add Machine Image Group '{image_group.name}' to "
+                f"Image Family '{fq_name}': {e}"
+            )
+
+    return image_family
 
 
 # Entry point
