@@ -133,7 +133,11 @@ RN_UPDATE_GROUP_REQUEST = "UpdateGroupRequest"
 RN_USER = "User"
 
 # Property Names
+PROP_ACCESS_DELEGATES = "accessDelegates"
+PROP_ADMIN_GROUP = "adminGroup"
 PROP_AUTOSCALING_MAX_NODES = "autoscalingMaxNodes"
+PROP_CREATED_BY_USER_ID = "createdByUserId"
+PROP_CREATED_TIME = "createdTime"
 PROP_CREDENTIAL = "credential"
 PROP_CST_ID = "sourceTemplateId"
 PROP_DEFAULT_RANK_ORDER = "defaultRankOrder"
@@ -145,6 +149,7 @@ PROP_ID = "id"
 PROP_IMAGE = "image"
 PROP_IMAGES_ID = "imagesId"
 PROP_IMAGE_ID = "imageId"
+PROP_INSTANCE_PRICING = "instancePricing"
 PROP_KEYRING = "keyring"
 PROP_KEYRING_NAME = "keyringName"
 PROP_NAME = "name"
@@ -158,6 +163,8 @@ PROP_ROLES = "roles"
 PROP_SOURCE = "source"
 PROP_SOURCES = "sources"
 PROP_SOURCE_CREATED_FROM = "sourceCreatedFromId"
+PROP_SUPPORTING_RESOURCE_CREATED = "supportingResourceCreated"
 PROP_TITLE = "title"
+PROP_TRAITS = "traits"
 PROP_TYPE = "type"
 PROP_UNITS = "units"
